/*
h83048addr.h : port address of internal registers
*/

#define FLMCR   0xfff40 /* Flash memory control register */
#define EBR1	0xfff42 /* Erase block register 1 */
#define EBR2	0xfff43	/* Erase block register 2 */
#define RAMCR	0xfff48	/* RAM control register */

#define MDCR	0xffff1	/* Mode control register */
#define SYSCR	0xffff2 /* System control register */

/* Power-Down State */
#define MSTCR	0xfff5e /* Module standby control register */

/* Clock Pulse Generator */
#define DIVCR	0xfff5d /* Division control register */
/* 0: 1/1
 * 1: 1/2
 * 2: 1/4
 * 3: 1/8
 */

/* Watchdog Timer */
/* 8bit up counter (source 1/2,1/32,1/64,1/128,1/256,1/2048,1/4096 of CLK */
#define TCSR	0xfffa8 /* Timer control/status register */
#define TCNT	0xfffa9 /* Timer counter */
#define RSTCSR	0xfffab /* Reset control/status register */

/* Serail Communication */
#define SMR0	0xfffb0 /* Serial mode register 0 */
#define BRR0	0xfffb1 /* Bit rate register 0 */
#define SCR0	0xfffb2 /* Serial control register 0 */
#define TDR0	0xfffb3 /* Tansmit data register 0 */
#define SSR0	0xfffb4 /* Serial status register 0 */
#define RDR0	0xfffb5 /* Recieve data register 0 */

#define SMR1	0xfffb8 /* Serial mode register 1 */
#define BRR1	0xfffb9 /* Bit rate register 1 */
#define SCR1	0xfffba /* Serial control register 1 */
#define TDR1	0xfffbb /* Tansmit data register 1 */
#define SSR1	0xfffbc /* Serial status register 1 */
#define RDR1	0xfffbd /* Recieve data register 1 */

/* 16-Bit integrated Timer */
#define TSTR	0xfff60 /* Timer start register */
#define TSNC	0xfff61 /* Timer synchro register */
#define TMDR	0xfff62 /* Timer mode register */
#define TFCR	0xfff63 /* Timer function control register */
#define TOER	0xfff90 /* Timer output master enable register */
#define TOCR	0xfff91 /* Timer output control register */

#define TCR0	0xfff64 /* Timer control register 0 */
#define TIOR0	0xfff65 /* Timer I/O control register 0 */
#define TIER0	0xfff66 /* Timer interrupt enable  register 0 */
#define TSR0	0xfff67 /* Timer status register 0 */
#define TCNT0H	0xfff68 /* Timer counter 0 (high) */
#define TCNT0L	0xfff69 /* Timer counter 0 (low) */
#define GRA0H	0xfff6a /* General register A0 (high) */
#define GRA0L	0xfff6b /* General register A0 (low) */
#define GRB0H	0xfff6c /* General register B0 (high) */
#define GRB0L	0xfff6d /* General register B0 (low) */

#define TCR1	0xfff6e /* Timer control register 1 */
#define TIOR1	0xfff6f /* Timer I/O control register 1 */
#define TIER1	0xfff70 /* Timer interrupt enable  register 1 */
#define TSR1	0xfff71 /* Timer status register 1 */
#define TCNT1H	0xfff72 /* Timer counter 1 (high) */
#define TCNT1L	0xfff73 /* Timer counter 1 (low) */
#define GRA1H	0xfff74 /* General register A1 (high) */
#define GRA1L	0xfff75 /* General register A1 (low) */
#define GRB1H	0xfff76 /* General register B1 (high) */
#define GRB1L	0xfff77 /* General register B1 (low) */

#define TCR2	0xfff78 /* Timer control register 2 */
#define TIOR2	0xfff79 /* Timer I/O control register 2 */
#define TIER2	0xfff7a /* Timer interrupt enable  register 2 */
#define TSR2	0xfff7b /* Timer status register 2 */
#define TCNT2H	0xfff7c /* Timer counter 2 (high) */
#define TCNT2L	0xfff7d /* Timer counter 2 (low) */
#define GRA2H	0xfff7e /* General register A2 (high) */
#define GRA2L	0xfff7f /* General register A2 (low) */
#define GRB2H	0xfff80 /* General register B2 (high) */
#define GRB2L	0xfff81 /* General register B2 (low) */

#define TCR3	0xfff82 /* Timer control register 3 */
#define TIOR3	0xfff83 /* Timer I/O control register 3 */
#define TIER3	0xfff84 /* Timer interrupt enable  register 3 */
#define TSR3	0xfff85 /* Timer status register 3 */
#define TCNT3H	0xfff86 /* Timer counter 3 (high) */
#define TCNT3L	0xfff87 /* Timer counter 3 (low) */
#define GRA3H	0xfff88 /* General register A3 (high) */
#define GRA3L	0xfff89 /* General register A3 (low) */
#define GRB3H	0xfff8a /* General register B3 (high) */
#define GRB3L	0xfff8b /* General register B3 (low) */
#define BRA3H	0xfff8c /* Buffer register A3 (high) */
#define BRA3L	0xfff8d /* Buffer register A3 (low) */
#define BRB3H	0xfff8e /* Buffer register B3 (high) */
#define BRB3L	0xfff8f /* Buffer register B3 (low) */

#define TCR4	0xfff92 /* Timer control register 4 */
#define TIOR4	0xfff93 /* Timer I/O control register 4 */
#define TIER4	0xfff94 /* Timer interrupt enable  register 4 */
#define TSR4	0xfff95 /* Timer status register 4 */
#define TCNT4H	0xfff96 /* Timer counter 4 (high) */
#define TCNT4L	0xfff97 /* Timer counter 4 (low) */
#define GRA4H	0xfff98 /* General register A4 (high) */
#define GRA4L	0xfff99 /* General register A4 (low) */
#define GRB4H	0xfff9a /* General register B4 (high) */
#define GRB4L	0xfff9b /* General register B4 (low) */
#define BRA4H	0xfff9c /* Buffer register A4 (high) */
#define BRA4L	0xfff9d /* Buffer register A4 (low) */
#define BRB4H	0xfff9e /* Buffer register B4 (high) */
#define BRB4L	0xfff9f /* Buffer register B4 (low) */

/* Interrupt Controler */
#define ISCR	0xffff4	/* IRQ sense control register */
#define IER	0xffff5	/* IRQ enable register */
#define ISR	0xffff6	/* IRQ status register */
#define IPRA	0xffff8	/* interrupt priority register A */
#define IPRB	0xffff9	/* interrupt priority register A */
/*#define SYSCR	0xffff2	/* System control register */

/* I/O Ports */
/* 
 * Port 1: 8bit 90pF,LED                          
 * Port 2: 8bit 90pF,LED                      ,pull-up MOS
 * Port 3: 8bit 90pF                          
 * Port 4: 8bit 90pF                          ,pull-up MOS
 * Port 5: 4bit 90pF,LED                      ,pull-up MOS
 * Port 6: 7bit 30pF                           
 * Port 7: 8bit                                            A/D
 * Port 8: 5bit 90pF       0-2 Schmitt-trigger 		   IRQ0-3
 * Port 9: 6bit 30pF                                       SIO,IRQ4-5
 * Port A: 8bit 30pF       0-7 Schmitt-trigger 
 * Port B: 8bit 30pF,LED   0-3 Schmitt-trigger 
 */

#define P1DDR	0xfffc0	/* Port 1 data direction register */
#define P1DR	0xfffc2 /* Port 1 data register */

#define P2DDR	0xfffc1	/* Port 2 data direction register */
#define P2DR	0xfffc3 /* Port 2 data register */
#define P2PCR	0xfffd8 /* Port 2 input pull-up MOS control register */

#define P3DDR	0xfffc4	/* Port 3 data direction register */
#define P3DR	0xfffc6 /* Port 3 data register */

#define P4DDR	0xfffc5	/* Port 4 data direction register */
#define P4DR	0xfffc7 /* Port 4 data register */
#define P4PCR	0xfffda /* Port 4 input pull-up MOS control register */

#define P5DDR	0xfffc8	/* Port 5 data direction register */
#define P5DR	0xfffca /* Port 5 data register */
#define P5PCR	0xfffdb /* Port 5 input pull-up MOS control register */

#define P6DDR	0xfffc9	/* Port 6 data direction register */
#define P6DR	0xfffcb /* Port 6 data register */

#define P7DR	0xfffce /* Port 7 data register */

#define P8DDR	0xfffcd	/* Port 8 data direction register */
#define P8DR	0xfffcf /* Port 8 data register */

#define P9DDR	0xfffd0	/* Port 9 data direction register */
#define P9DR	0xfffd2 /* Port 9 data register */

#define PADDR	0xfffd1	/* Port A data direction register */
#define PADR	0xfffd3 /* Port A data register */

#define PBDDR	0xfffd4	/* Port B data direction register */
#define PBDR	0xfffd6 /* Port B data register */

#define outb(addr,dat) (*(volatile unsigned char*)(addr)=(dat))
#define outw(addr,dat) (*(volatile unsigned int*)(addr)=(dat))
#define inb(addr) (*(volatile unsigned char*)(addr))
#define inw(addr) (*(volatile unsigned int*)(addr))

#define orb(addr,dat) (*(volatile unsigned char*)(addr) |=(dat))
#define andb(addr,dat) (*(volatile unsigned char*)(addr) &=(dat))
