/*
    writebyte.S : write one byte to EEPROM
*/

;a 40
;b 12
;c 12
;d 1516
;e 12
;f 15
;g 7

#include "h83048addr.h"

#define AAAA #40
#define GGGG #7
#define BBBB #12
#define WDTVAL #0xA57F

; writebyte : write 1 byte to EEPROM
; int writebyte(int addr,unsigned char* value)
;
	.h8300h
	.section .text
	.align 1
	.global _writebyte
_writebyte:
	push	er6
	mov.l	er7,er6
	sub	#8,sp

	push	er1
	push	er2
	push	er3
	push	er4

	mov.l	@(-20,er6),er1	; addr
	mov.b	@(-21,er6),r2l	; data
	mov.b	r2l,r0l
	pop	er4
	pop	er3
	pop	er2
	pop	er1
	add	#8,sp
	pop.l	er6
	rts
	jmp	_EXIT

	mov.l	er1,er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0
	shlr	er0

	mov.b	#0,r2h		; bank

	mov.w	#0001, r3 ; Program-verify fail count
	mov.b	#40,r0l
	mov.b	r0l,@FLMCR:8

	mov.w	GGGG, r0 ; Set program loop counter
_LOOP0:	dec.w	#1, r0 ;
	bpl	_LOOP0

	mov.b	r2h, @EBR1:8 ; Set EBR1
	mov.b	r2l, @er1 ; Dummy write

	mov.w	AAAA, r4 ; Set initial program loop counter value
PRGMS:	mov.w	WDTVAL, r0 ; Start watchdog timer
	mov.w	r0, @TCSR:16 ;
	mov.w	#4140, r0 ;
	mov.b	r0h, @FLMCR:8 ; Set P bit

	mov.w	r4, r0 ; Set program loop counter
_LOOP1:	dec.w	#1, r0 ; Program
	bpl	_LOOP1

	mov.w	#4140, r0
	mov.b	r0l, @FLMCR:8 ; Clear P bit

	mov.w	#0xA500, r0 ;
	mov.w	r0, @TCSR:16 ; Stop watchdog timer

	mov.b	#44, r0h ;
	mov.b	r0h, @FLMCR:8 ; Set PV bit

	mov.w	BBBB , r0 ; Set program-verify loop counter
_LOOP2:	dec.w	#1, r0 ; Wait
	bpl	_LOOP2

	mov.b	@er1,r0l
	cmp.b	r2l,r0l

	beq	PVOK ; Program-verify decision
PVNG:	mov.b	#40, r0h ;
	mov.b	r0h, @FLMCR:8 ; Clear PV bit
	cmp.b	#06, r3l ; Program-verify executed 6 times?
	beq	NGEND ; If program-verify executed 6 times, branch to NGEND
	inc.b	r3l ; Program-verify fail count + 1 ,A. R0L
	shll.w	r4 ; Double program loop counter value
	bra	PRGMS ; Program again
PVOK:	mov.w	#4000, r0 ;
	mov.b	r0h, @FLMCR:8 ; Clear PV bit
	mov.b	r0l, @EBR1:8 ;Clear EBR1
	mov.b	r0l, @FLMCR:8 ;Clear V PP E bit One byte programmed
	sub	r0,r0
	bra	_EXIT

NGEND:	mov.w	#4000, r0 ;
	mov.b	r0l, @EBR1:8 ;Clear EBR1
	MOV.B	r0l, @FLMCR:8 ;Clear VPP E bit
	mov.w	#-1,r0

_EXIT:
	pop	er4
	pop	er3
	pop	er2
	pop	er1
	add	#8,sp
	pop.l	er6
	rts
	.end